@@ -16,8 +16,22 @@ except ImportError:
 #import numpy as np  
 #import pandas as pd
 
-def make_subplot(*args, **kwargs):
-    subplot = {'cmd': []}
+def make_plot(*args, **kwargs):
+    subplot = {'subtype': 'splot',
+            'cmd': [] }
+    subplot["attribute"] = collections.OrderedDict()
+
+    subplot["attribute"] = collections.OrderedDict()
+
+    for v in args:
+        subplot["cmd"].append(v)
+    for k,v in kwargs.items():
+        subplot["attribute"][k] = v
+    return subplot
+
+def make_splot(*args, **kwargs):
+    subplot = {'subtype': 'plot',
+            'cmd': [] }
     subplot["attribute"] = collections.OrderedDict()
 
     for v in args:
@@ -49,9 +63,9 @@ def multiplot(*args, **kwargs):
                 #print('set %s %s' %(k, v))
                 g.cmd('set %s %s' %(k, v))
         cmd = subplot["cmd"]
-        c = 'plot '
+        c = subplot["subtype"]
         for cmd in subplot["cmd"]:
-            c += '$Mydata %s, ' %(cmd)
+            c += ' $Mydata %s, ' %(cmd)
         #print(c)
         g.cmd(c)
         # multiplot automatically unset all the label after one subplot.
