@@ -14,8 +14,21 @@ import pandas as pd
 def test():
     print("gplfinance.test()")
 
-def make_subplot(data, *args, **kwargs):
+def make_splot(data, *args, **kwargs):
     subplot = {'data': data,
+            'subtype': 'splot',
+            'cmd': []}
+    subplot["attribute"] = collections.OrderedDict()
+
+    for v in args:
+        subplot["cmd"].append(v)
+    for k,v in kwargs.items():
+        subplot["attribute"][k] = v
+    return subplot
+
+def make_plot(data, *args, **kwargs):
+    subplot = {'data': data,
+            'subtype': 'plot',
             'cmd': []}
     subplot["attribute"] = collections.OrderedDict()
 
@@ -44,14 +57,20 @@ def multiplot(*args, **kwargs):
                 #print('set %s %s' %(k, v))
                 g.cmd('set %s %s' %(k, v))
         cmd = subplot["cmd"]
-        g.cmd('$Mydata << EOD\n%s\nEOD' %(subplot["data"]))
-        c = 'plot '
+
+        # Conver the data to string format:
+        if isinstance(subplot["data"], pd.DataFrame):
+            content = subplot["data"].to_csv(sep = ' ')
+        else:
+            content = str(data)
+        g.cmd('$Mydata << EOD\n%s\nEOD' %(content))
+        c = subplot["subtype"]
         for cmd in subplot["cmd"]:
-            c += '$Mydata %s, ' %(cmd)
+            c += ' $Mydata %s, ' %(cmd)
         #print(c)
         g.cmd(c)
         # multiplot automatically unset all the label after one subplot.
-        g.cmd('unset for [i=1:200] label i')
+        g.cmd('unset for [i=1:50] label i')
     g.reset()
 
 def plot(data, *args, **kwargs):
@@ -75,6 +94,7 @@ def __gnuplot(data, plot_cmd, *args, **kwargs):
             #print('set %s %s' %(k, v))
             g.cmd('set %s %s' %(k, v))
 
+    # Conver the data to string format:
     if isinstance(data, pd.DataFrame):
         content = data.to_csv(sep = ' ')
     else:
